# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['secrets_env']

package_data = \
{'': ['*']}

install_requires = \
['hvac>=0.11.2,<0.12.0', 'keyring>=23.6.0,<24.0.0', 'requests>=2.28.1,<3.0.0']

extras_require = \
{'toml:python_version < "3.11"': ['tomli>=2.0.1,<3.0.0'],
 'yaml': ['PyYAML>=6.0,<7.0']}

entry_points = \
{'poetry.application.plugin': ['poetry-secrets-env-plugin = '
                               'secrets_env.poetry:SecretsEnvPlugin']}

setup_kwargs = {
    'name': 'secrets.env',
    'version': '0.7.1',
    'description': 'Put secrets from Vault to environment variables',
    'long_description': '# Secrets.env 🔓\n\n[![PyPI version](https://img.shields.io/pypi/v/secrets.env)](https://pypi.org/project/secrets.env/)\n![Python version](https://img.shields.io/pypi/pyversions/secrets.env)\n[![test result](https://img.shields.io/github/workflow/status/tzing/secrets.env/Tests)](https://github.com/tzing/secrets.env/actions/workflows/test.yml)\n\nPut secrets from [Vault](https://www.vaultproject.io/) KV engine to environment variables like a `.env` loader, without not landing data on disk.\n\nSecurity is important, but don\'t want it to be a stumbling block. We love secret manager, but the practice of getting secrets for local development could be dangerous- some of us put the sensitive data into a shell script and source it, which brings the risk of credential leaking.\n\nThis tool is built to *plug in* secrets into development without landing data on disk. Furthermore, we can safely commit the config file into CVS, for easily reproducing the environment, and reduce the risk of uploading the secrets to the server.\n\n\n## Usage\n\n> **Note**\n>\n> Standard CLI usage is not implemented yet.\n> Currently this app could only be used as a poetry plugin. Plugin is a poetry **1.2.0** feature, which is still in beta testing.\n\nGet it from [PyPI](https://pypi.org/project/secrets.env/):\n\n```bash\n# add as poetry global plugin\npoetry self add secrets.env -E yaml\n\n# add to local project\npoetry add --group=dev secrets.env -E toml\n```\n\nFolowing extras avaliable:\n\n* `yaml`: supporting YAML config\n* `toml`: supporting TOML config, includes `pyproject.toml`\n\nIf none of them are selected, this app only supports the config in JSON format.\n\n### With poetry\n\nYou can use this package as a [poetry plugin](https://python-poetry.org/docs/master/plugins/), then this app will pull the secrets from vault on poetry command `run` and `shell`.\n\n```bash\n# 1. install plugin\npoetry add --group=dev secrets.env -E yaml\n\n# 2. setup config\n#    read configuration section below for details\nexport SECRETS_ENV_ADDR=\'https://example.com\'\nexport SECRETS_ENV_METHOD=\'token\'\nexport SECRETS_ENV_TOKEN=\'example-token\'\n\necho \'secrets:\'                       > .secrets-env.yaml\necho \'  FOO=secrets/default#example\'  > .secrets-env.yaml\n\n# 3. run\npoetry run sh -c \'echo $FOO\'\n```\n\n\n## Configure\n\n### Configuration file\n\nThis app searches for the file that matches following names in the current working directory and parent folders, and load the config from it. When there are more than one exists, the first one would be selected according to the order here:\n\n1. `.secrets-env.toml`[^1]\n2. `.secrets-env.yaml`[^2]\n3. `.secrets-env.yml`[^2]\n4. `.secrets-env.json`\n5. `pyproject.toml`[^1]\n\n[^1]: TOML format is only supported when either [tomllib](https://docs.python.org/3.11/library/tomllib.html) or [tomli](https://pypi.org/project/tomli/) is installed.\n[^2]: YAML format is only supported when [PyYAML](https://pypi.org/project/PyYAML/) is installed.\n\nAn example config in YAML format:\n\n```yaml\n# `source` configured the connection info to vault.\n# All values in this section could be overwritten by environment variable, so\n# it is possible to run secrets.env app without this section.\nsource:\n  # Address to vault\n  # Could be replaced using environment variable `SECRETS_ENV_ADDR` or `VAULT_ADDR`\n  url: https://example.com/\n\n  # Authentication info\n  # Schema for authentication could be complex, read section below.\n  auth:\n    method: okta\n    username: user@example.com\n\n# `secrets` lists the environment variable name, and the path the get the secret value\nsecrets:\n  # The key (VAR1) is the environment variable name to install the secret\n  VAR1:\n    # Path to read secret from vault\n    path: kv/default\n\n    # Path to identify which value to extract, as we may have multiple values in\n    # single secret in KV engine.\n    # For nested structure, join the keys with dots.\n    key: example.to.value\n\n  # Syntax sugar: path#key\n  VAR2: "kv/default#example.to.value"\n```\n\n> For most supported file format, they shared the same schema to this example. The only different is [`pyproject.toml`](./example/pyproject.toml) format- each section must placed under `tool.secrets-env` section.\n> Visit [example folder](./example/) to read the equivalent expression in each format.\n\n### Authentication\n\nVault enforce authentication during requests, so we must provide the identity in order to get the secrets.\n\n*Method*\n\nSecrets.env adapts several authentication methods. You must specify the method by either config file or the environment variable `SECRETS_ENV_METHOD`. Here\'s the format in config file:\n\n```yaml\n---\n# standard layout\n# arguments could be included in `auth:`\nsource:\n  auth:\n    method: okta\n    username: user@example.com\n\n---\n# alternative layout\n# arguments must be avaliable in other source\nsource:\n  auth: token\n```\n\n*Arguments*\n\nAuth data could be provided by various source, including:\n\n* **Config file:** Place the config value under `auth` section, use the key provided in the table.\n* **Environment variable:** In most cases, environment variable could be used to overwrite the values from config file.\n* **Keyring:** We\'re using [keyring] package to read the values from system keyring (e.g. macOS [Keychain]). For saving a value into keyring, use its [command line utility] with the system name `secrets.env`:\n\n  ```bash\n  keyring get secrets.env token/:token\n  keyring set secrets.env okta/test@example.com\n  ```\n\n  [keyring]: https://keyring.readthedocs.io/en/latest/\n  [Keychain]: https://en.wikipedia.org/wiki/Keychain_%28software%29\n  [command line utility]: https://keyring.readthedocs.io/en/latest/#command-line-utility\n\n* **Prompt:** If no data found in all other sources, it prompts user for input. Prompt is only enabled when optional dependency [click](https://click.palletsprojects.com/en/8.1.x/) is installed, and you can disable it by setting environment variable `SECRETS_ENV_NO_PROMPT=True`.\n\n#### Supported methods\n\nHere\'s the argument(s), their accepted source, and corresponding keys.\n\n##### method: `token`\n\n| key   | config file | environment variable                | keyring        | helper |\n|-------|:------------|:------------------------------------|:---------------|--------|\n| token | ⛔️          | `SECRETS_ENV_TOKEN`, `VAULT_TOKEN`  | `token/:token` | ✅     |\n\n*[Token helper](https://www.vaultproject.io/docs/commands/token-helper)*: Vault CLI stores the generated token in the `~/.vault-token` file after authenticated. This app reads the token from that file, but it do not create one on authenticating using this app.\n\nTo use the helper, you can use command [`vault login`](https://www.vaultproject.io/docs/commands/login) to create one.\n\n##### method: `okta`\n\n| key      | config file | environment variable   | keyring               | prompt |\n|----------|:------------|:-----------------------|:----------------------|--------|\n| username | `username`  | `SECRETS_ENV_USERNAME` | `okta/:username`      | ✅     |\n| password | ⛔️          | `SECRETS_ENV_PASSWORD` | `okta/YOUR_USER_NAME` | ✅     |\n',
    'author': 'tzing',
    'author_email': 'tzingshih@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/tzing/secrets.env',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
